<?php # $Id: serendipity_lang_zh.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translated by
# (c) 2006 Aphonex Li <aphonex.li@gmail.com> 
#          http://www.cexten.com  
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'gb2312');
@define('SQL_CHARSET', 'gb2312');
@define('DATE_LOCALES', 'zh_CN.GB2312, cn, zh, zh_GB, zh_CN');
@define('DATE_FORMAT_SHORT', '%Y-%m-%d %H:%M');
@define('WYSIWYG_LANG', 'en');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', '.');
@define('NUMBER_FORMAT_THOUSANDS', ',');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', 'Serendipityܲϵͳ'); // ̨ҳ
@define('HAVE_TO_BE_LOGGED_ON', 'ȵ');
@define('WRONG_USERNAME_OR_PASSWORD', 'ʺŻ');
@define('APPEARANCE', 'Ҫ');
@define('MANAGE_STYLES', '');
@define('CONFIGURE_PLUGINS', '趨');
@define('CONFIGURATION', '趨');
@define('BACK_TO_BLOG', 'վҳ');
@define('LOGIN', '');
@define('LOGOUT', 'ǳ');
@define('LOGGEDOUT', 'ǳ');
@define('CREATE', '');
@define('SAVE', '');
@define('NAME', '');
@define('CREATE_NEW_CAT', '');
@define('I_WANT_THUMB', 'ʹͼ.');
@define('I_WANT_BIG_IMAGE', 'ʹôͼƬ.');
@define('I_WANT_NO_LINK', 'ͼƬʾ');
@define('I_WANT_IT_TO_LINK', 'ʾַ:');
@define('BACK', '');
@define('FORWARD', 'ǰ');
@define('ANONYMOUS', '');
@define('NEW_TRACKBACK_TO', 'µõ');
@define('NEW_COMMENT_TO', 'µĻظ');
@define('RECENT', 'Ŀ...');
@define('OLDER', 'Ŀ...');
@define('DONE', '');
@define('WELCOME_BACK', 'ǳ˼,');
@define('TITLE', '');
@define('DESCRIPTION', '');
@define('PLACEMENT', 'ַ');
@define('DELETE', 'ɾ');
@define('SAVE', '');
@define('UP', '');
@define('DOWN', '');
@define('ENTRIES', '¹');
@define('NEW_ENTRY', '');
@define('EDIT_ENTRIES', '༭');
@define('CATEGORIES', '');
@define('WARNING_THIS_BLAHBLAH', ":\\nкܶͼƬĻҪܳʱ䡣");
@define('CREATE_THUMBS', 'ؽϸͼ');
@define('MANAGE_IMAGES', 'ͼƬ');
@define('NAME', '');
@define('EMAIL', '');
@define('HOMEPAGE', 'ַ');
@define('COMMENT', 'ظ');
@define('REMEMBER_INFO', '¼');
@define('SUBMIT_COMMENT', 'ͻظ');
@define('NO_ENTRIES_TO_PRINT', 'û');
@define('COMMENTS', 'ظ'); // ҳ
@define('ADD_COMMENT', 'ظ');
@define('NO_COMMENTS', 'ûлظ');
@define('POSTED_BY', '');
@define('ON', '');
@define('A_NEW_COMMENT_BLAHBLAH', '»ظѷվ "%s",  "%s"');
@define('A_NEW_TRACKBACK_BLAHBLAH', ' "%s" µá');
@define('NO_CATEGORY', 'û');
@define('ENTRY_BODY', '');
@define('EXTENDED_BODY', '¸');
@define('CATEGORY', 'ȫ'); // ҳ
@define('EDIT', '༭');
@define('NO_ENTRIES_BLAHBLAH', 'Ҳѯ %s ' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'Ѱ %s ʾ %s :');
@define('IMAGE', 'ͼƬ');
@define('ERROR_FILE_NOT_EXISTS', ': ļڣ');
@define('ERROR_FILE_EXISTS', ': ļѱʹ, 룡');
@define('ERROR_SOMETHING', '');
@define('ADDING_IMAGE', 'ͼƬ...');
@define('THUMB_CREATED_DONE', 'ͼ<br>ɣ');
@define('ERROR_FILE_EXISTS_ALREADY', ': ļѴ');
@define('ERROR_UNKNOWN_NOUPLOAD', ', ļûϴΪļƵĴС ѯ̻޸ php.ini ļԡ');
@define('GO', '');
@define('NEWSIZE', 'С: ');
@define('RESIZE_BLAHBLAH', '<b>С %s</b><p>');
@define('ORIGINAL_SIZE', 'ԭеĴС: <i>%sx%s</i> ');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>޸ͼƬСҪ޸ĳͬͼƬ, ֻҪһֵȻ TAB -- ϵͳԶ</p>');
@define('QUICKJUMP_CALENDAR', 'Ծ');
@define('QUICKSEARCH', 'Ѱ');
@define('SEARCH_FOR_ENTRY', 'Ѱ');
@define('ARCHIVES', '¹鵵');
@define('BROWSE_ARCHIVES', '·ݱ');
@define('TOP_REFERRER', 'ҪԴ');
@define('SHOWS_TOP_SITES', 'ʾӵվ');
@define('TOP_EXITS', 'ҪԴ');
@define('SHOWS_TOP_EXIT', 'ʾվҪԴ');
@define('SYNDICATION', 'ͬ');
@define('SHOWS_RSS_BLAHBLAH', 'ʾ RSS ͬ');
@define('ADVERTISES_BLAHBLAH', '־');
@define('HTML_NUGGET', 'HTML Ϣ');
@define('HOLDS_A_BLAHBLAH', 'ʾ HTML ѶϢ');
@define('TITLE_FOR_NUGGET', 'Ϣ');
@define('THE_NUGGET', 'HTML ѶϢ');
@define('SYNDICATE_THIS_BLOG', 'ϲ˵');
@define('YOU_CHOSE', 'ѡ %s');
@define('IMAGE_SIZE', 'ͼƬС');
@define('IMAGE_AS_A_LINK', 'ͼƬ');
@define('POWERED_BY', 'վϢ');
@define('TRACKBACKS', '');
@define('TRACKBACK', '');
@define('NO_TRACKBACKS', 'û');
@define('TOPICS_OF', '');
@define('VIEW_FULL', 'ȫ');
@define('VIEW_TOPICS', '');
@define('AT', 'ʱ');
@define('SET_AS_TEMPLATE', 'ʹ');
@define('IN', '');
@define('EXCERPT', 'ժҪ');
@define('TRACKED', '');
@define('LINK_TO_ENTRY', 'ӵ');
@define('LINK_TO_REMOTE_ENTRY', 'ӵԶ');
@define('IP_ADDRESS', 'IP ַ');
@define('USER', '');
@define('THUMBNAIL_USING_OWN', 'ʹ %s ͼߴΪͼƬѾСˡ');
@define('THUMBNAIL_FAILED_COPY', 'ʹ %s ͼ, ޷ƣ');
@define('AUTHOR', '');
@define('LAST_UPDATED', '');
@define('TRACKBACK_SPECIFIC', 'ôضַ');
@define('DIRECT_LINK', 'ֱӵ');
@define('COMMENT_ADDED', 'Ļظѳɹ ');
@define('COMMENT_ADDED_CLICK', ' %sﷵ%s ظ, ͵ %sر%s Ӵ');
@define('COMMENT_NOT_ADDED_CLICK', ' %sﷵ%s ظ, ͵ %sر%s Ӵ');
@define('COMMENTS_DISABLE', 'ظƪ');
@define('COMMENTS_ENABLE', 'ظƪ');
@define('COMMENTS_CLOSED', '߲ظƪ');
@define('EMPTY_COMMENT', 'ĻظûκϢ,  %s%s ');
@define('ENTRIES_FOR', '¸ %s');
@define('DOCUMENT_NOT_FOUND', 'Ҳƪļ %s');
@define('USERNAME', 'ʺ');
@define('PASSWORD', '');
@define('AUTOMATIC_LOGIN', 'Զ');
@define('SERENDIPITY_INSTALLATION', 'Serendipity װ');
@define('LEFT', '');
@define('RIGHT', '');
@define('HIDDEN', '');
@define('REMOVE_TICKED_PLUGINS', 'Ƴѡ');
@define('SAVE_CHANGES_TO_LAYOUT', '');
@define('COMMENTS_FROM', 'ظԴ');
@define('ERROR', '');
@define('ENTRY_SAVED', 'ѱ');
@define('DELETE_SURE', 'ȷҪɾ #%s ');
@define('NOT_REALLY', '...');
@define('DUMP_IT', 'ɾ');
@define('RIP_ENTRY', 'R.I.P.  #%s');
@define('CATEGORY_DELETED_ARTICLES_MOVED', ' #%s ɾ. ѱƶ #%s');
@define('CATEGORY_DELETED', ' #%s ɾ');
@define('INVALID_CATEGORY', 'ûṩɾ');
@define('CATEGORY_SAVED', 'ѱ');
@define('SELECT_TEMPLATE', 'ѡ־');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'û£');
@define('MT_DATA_FILE', 'Movable Type ');
@define('FORCE', 'ǿ');
@define('CREATE_AUTHOR', ' \'%s\'.');
@define('CREATE_CATEGORY', ' \'%s\'.');
@define('MYSQL_REQUIRED', 'Ҫ MySQL 书ִܲ');
@define('COULDNT_CONNECT', 'ӵ MySQL Ͽ: %s.');
@define('COULDNT_SELECT_DB', 'ѡݿ: %s.');
@define('COULDNT_SELECT_USER_INFO', 'ѡʹߵ: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'ѡ: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'ѡµ: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'ѡظ: %s.');
@define('YES', '');
@define('NO', '');
@define('USE_DEFAULT', 'Ԥ');
@define('CHECK_N_SAVE', '');
@define('DIRECTORY_WRITE_ERROR', 'ܶдļ %sȨޣ');
@define('DIRECTORY_CREATE_ERROR', 'ļ %s Ҳ޷ԼļУ');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; run <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', '޷ִ %s ļ');
@define('FILE_WRITE_ERROR', '޷дļ %s');
@define('FILE_CREATE_YOURSELF', 'ԼļȨ');
@define('COPY_CODE_BELOW', '<br />* 븴ĴȻ %s  %s ļ:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'ı www ʹߵ Apache (i.e. nobody)');
@define('BROWSER_RELOAD', '֮, ˢ.');
@define('DIAGNOSTIC_ERROR', 'ϵͳ⵽һЩ:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity ûװ. 밴 <a href="%s">װ</a>.');
@define('INCLUDE_ERROR', 'serendipity : ޷ %s - ˳');
@define('DATABASE_ERROR', 'serendipity : ޷ӵ - ˳');
@define('CHECK_DATABASE_EXISTS', 'ݿǷڡ 㿴ݿѯ, ǷҪװ...');
@define('CREATE_DATABASE', 'Ԥݿ趨...');
@define('ATTEMPT_WRITE_FILE', 'д %s ļ...');
@define('SERENDIPITY_INSTALLED', 'Serendipity İ汾 Ѱװɣ%s ǵ: "%s", ʺ "%s".%sڿԵ½ <a href="%s">ռ</a>');
@define('WRITTEN_N_SAVED', '');
@define('IMAGE_ALIGNMENT', 'ͼƬ');
@define('ENTER_NEW_NAME', ': ');
@define('RESIZING', 'С');
@define('RESIZE_DONE', ' ( %s ͼƬ)');
@define('SYNCING', 'ݿͼƬļͬ');
@define('SYNC_DONE', ' (ͬ %s ͼƬ)');
@define('FILE_NOT_FOUND', 'Ҳļ <b>%s</b>, ѱɾ');
@define('ABORT_NOW', '');
@define('REMOTE_FILE_NOT_FOUND', 'ļԶ, ȷַ: <b>%s</b> ȷġ');
@define('FILE_FETCHED', '%s ȡΪ %s');
@define('FILE_UPLOADED', 'ļ %s ϴΪ %s');
@define('WORD_OR', '');
@define('SCALING_IMAGE', ' %s  %s x %s ');
@define('KEEP_PROPORTIONS', 'άֱ');
@define('REALLY_SCALE_IMAGE', 'ȷҪͼƬ? ָܻ');
@define('TOGGLE_ALL', 'лչ');
@define('TOGGLE_OPTION', 'лѡ');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'ƪ');
@define('UNSUBSCRIBE_OK', "%s ȡƪ");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', '»ظĵ "%s"');
@define('SUBSCRIPTION_MAIL', " %s,\n\n㶩ĵµĻظ \"%s\",  \"%s\"\nظķ: %s\n\nҵ: %s\n\nԵȡ: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', " %s,\n\n㶩ĵµ \"%s\",  \"%s\"\nõ: %s\n\nҵ: %s\n\nԵȡ: %s\n");
@define('SIGNATURE', "\n-- \n%s is powered by Serendipity.\n <http://www.s9y.org>");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 feed');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 feed');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 feed');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 comments');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 feed');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', '˵ "managingEditor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  '˵ "webMaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'RSS feed ͼƬ');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'ͼƬ');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'ͼƬ߶');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'Աĵʼ, У (հ: ) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'ߵĵʼ, У (հ: ) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'ͼƬλַ URL,  GIF/JPEG/PNG ʽ, У (հ: serendipity-logo)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', ', . 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', ', . 400');
@define('SYNDICATION_PLUGIN_TTL', '˵ "ttl" (time-to-live)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'ڼӺ²ᱻվ¼ (հ: ) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'λ "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', '"pubDate"-˵ҪǶRSS-Ƶ, ʾµ');
@define('CONTENT', '');
@define('TYPE', '');
@define('DRAFT', 'ݸ');
@define('PUBLISH', '');
@define('PREVIEW', 'Ԥ');
@define('DATE', '');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', ': ṩڲȷ.  YYYY-MM-DD HH:MM ĸʽ');
@define('CATEGORY_PLUGIN_DESC', 'ʾ嵥');
@define('ALL_AUTHORS', 'ȫ');
@define('CATEGORIES_TO_FETCH', 'ʾ');
@define('CATEGORIES_TO_FETCH_DESC', 'ʾλߵ');
@define('PAGE_BROWSE_ENTRIES', 'ҳ %s  %s, ܹ %s ƪ');
@define('PREVIOUS_PAGE', 'һҳ');
@define('NEXT_PAGE', 'һҳ');
@define('ALL_CATEGORIES', 'ȫ');
@define('DO_MARKUP', 'ִбת');
@define('GENERAL_PLUGIN_DATEFORMAT', 'ڸʽ');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'µڸʽ, ʹ PHP  strftime() . (Ԥ: "%s")');
@define('ERROR_TEMPLATE_FILE', '޷ļ, ϵͳ');
@define('ADVANCED_OPTIONS', '߼ѡ');
@define('EDIT_ENTRY', '༭');
@define('HTACCESS_ERROR', 'Ҫİװ趨, ϵͳҪд ".htaccess"ΪȨ޴, ûа취Ϊ飬ıļȨ: <br />&nbsp;&nbsp;%s<br />Ȼˢ¡');
@define('SIDEBAR_PLUGINS', '');
@define('EVENT_PLUGINS', '¼');
@define('SORT_ORDER', '');
@define('SORT_ORDER_NAME', 'ļ');
@define('SORT_ORDER_EXTENSION', 'ļ');
@define('SORT_ORDER_SIZE', 'ļС');
@define('SORT_ORDER_WIDTH', 'ͼƬ');
@define('SORT_ORDER_HEIGHT', 'ͼƬ');
@define('SORT_ORDER_DATE', 'ϴ');
@define('SORT_ORDER_ASC', '');
@define('SORT_ORDER_DESC', 'ݼ');
@define('THUMBNAIL_SHORT', 'ͼ');
@define('ORIGINAL_SHORT', 'ԭʼ');
@define('APPLY_MARKUP_TO', 'ñǵ %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'һܵĵһ');
@define('SERENDIPITY_NEEDS_UPGRADE', 'ϵͳİ汾 %s,  Serendipity ڵİ汾 %s, ĳ<a href="%s"></a>');
@define('SERENDIPITY_UPGRADER_WELCOME', ', ӭʹ Serendipity ĸ³');
@define('SERENDIPITY_UPGRADER_PURPOSE', '³µ Serendipity 汾 %s.');
@define('SERENDIPITY_UPGRADER_WHY', 'Ѿ Serendipity %s, ϵͳûиݿ⣡');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'ݿ (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'ϵͳҵµ .sql , Щݱִвܼװ Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'ضİ汾');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'ûضİ汾');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'ȷҪִϵ?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'Լִ');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'ִ');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'Ҫκθ');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Serendipity ');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', '˸, ȷݿѰװ, װ');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', ' Serendipity Ѿ°汾Ϊ %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'Ե %s%s վҳ');
@define('MANAGE_USERS', '');
@define('CREATE_NEW_USER', '');
@define('CREATE_NOT_AUTHORIZED', '㲻޸ĸͬȨ޵');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', '㲻Ȩ޵');
@define('CREATED_USER', ' %s Ѿ');
@define('MODIFIED_USER', ' %s Ѿ');
@define('USER_LEVEL', 'Ȩ');
@define('DELETE_USER', 'Ҫɾ #%d %s? ҳдκ¡');
@define('DELETED_USER', ' #%d %s ѱɾ.');
@define('LIMIT_TO_NUMBER', 'Ҫʾ');
@define('ENTRIES_PER_PAGE', 'ÿҳʾ');
@define('XML_IMAGE_TO_DISPLAY', 'XML ť');
@define('XML_IMAGE_TO_DISPLAY_DESC','ӵ XML Feeds ĶͼƬʾ. дʹԤͼƬ,  \'none\' رܡ');

@define('DIRECTORIES_AVAILABLE', 'ｨýŵĿ¼');
@define('ALL_DIRECTORIES', 'ȫĿ¼');
@define('MANAGE_DIRECTORIES', 'Ŀ¼');
@define('DIRECTORY_CREATED', 'Ŀ¼ <strong>%s</strong> Ѿ');
@define('PARENT_DIRECTORY', 'Ŀ¼');
@define('CONFIRM_DELETE_DIRECTORY', 'ȷҪɾĿ¼ڵȫ %s');
@define('ERROR_NO_DIRECTORY', ': Ŀ¼ %s ');
@define('CHECKING_DIRECTORY', 'Ŀ¼ļ %s');
@define('DELETING_FILE', 'ɾļ %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'ɾδյĿ¼. ѡ "ǿɾ" ȷҪɾЩļ, Ȼڼ ڵļ:');
@define('DIRECTORY_DELETE_FAILED', 'ɾĿ¼ %s. Ȩ޻ѶϢ.');
@define('DIRECTORY_DELETE_SUCCESS', 'Ŀ¼ %s ɹɾ.');
@define('SKIPPING_FILE_EXTENSION', 'ļ: û %s ĸ');
@define('SKIPPING_FILE_UNREADABLE', 'Թļ: %s ܶȡ');
@define('FOUND_FILE', 'ҵ /޸ ĵ: %s');
@define('ALREADY_SUBCATEGORY', '%s ѾǴӷ %s');
@define('PARENT_CATEGORY', '');
@define('IN_REPLY_TO', 'ظ');
@define('TOP_LEVEL', '߲');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
@define('PERMISSIONS', 'Ȩ');
@define('SETTINGS_SAVED_AT', '趨Ѿ浽 %s');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'ݿ趨');
@define('INSTALL_CAT_DB_DESC', 'ȫݿϣϵͳҪЩϲ');
@define('INSTALL_DBTYPE', 'ݿ');
@define('INSTALL_DBTYPE_DESC', 'ݿ');
@define('INSTALL_DBHOST', 'ݿ');
@define('INSTALL_DBHOST_DESC', 'ݿ');
@define('INSTALL_DBUSER', 'ݿʺ');
@define('INSTALL_DBUSER_DESC', 'ݿʺ');
@define('INSTALL_DBPASS', '');
@define('INSTALL_DBPASS_DESC', 'ݿ');
@define('INSTALL_DBNAME', '');
@define('INSTALL_DBNAME_DESC', 'Ͽ');
@define('INSTALL_DBPREFIX', 'ǰ');
@define('INSTALL_DBPREFIX_DESC', 'ǰ,  serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', '·趨');
@define('INSTALL_CAT_PATHS_DESC', 'ļе·. Ҫб!');
@define('INSTALL_FULLPATH', 'ȫ·');
@define('INSTALL_FULLPATH_DESC', 'ϵͳװ·;·');
@define('INSTALL_UPLOADPATH', 'ϴ·');
@define('INSTALL_UPLOADPATH_DESC', 'ȫϴļ浽,  \'ȫ·\' ʾ· -  \'uploads/\'');
@define('INSTALL_RELPATH', '·');
@define('INSTALL_RELPATH_DESC', '·,  \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Ե·');
@define('INSTALL_RELTEMPLPATH_DESC', '· -  \'·\' ʾ·');
@define('INSTALL_RELUPLOADPATH', 'Եϴ·');
@define('INSTALL_RELUPLOADPATH_DESC', 'ϴļ· -  \'·\' ʾ·');
@define('INSTALL_URL', 'վַ');
@define('INSTALL_URL_DESC', 'ϵͳװĻַ');
@define('INSTALL_INDEXFILE', 'Index ļ');
@define('INSTALL_INDEXFILE_DESC', 'ϵͳ index ļ');

/* Generel settings */
@define('INSTALL_CAT_SETTINGS', 'һ趨');
@define('INSTALL_CAT_SETTINGS_DESC', 'ϵͳһ趨');
@define('INSTALL_USERNAME', 'Աʺ');
@define('INSTALL_USERNAME_DESC', 'Ա½ϵͳʺ');
@define('INSTALL_PASSWORD', 'Ա');
@define('INSTALL_PASSWORD_DESC', 'Ա½ϵͳ');
@define('INSTALL_EMAIL', 'ʼ');
@define('INSTALL_EMAIL_DESC', 'Աĵʼ');
@define('INSTALL_SENDMAIL', '͵ʼԱ');
@define('INSTALL_SENDMAIL_DESC', '˻ظʱҪյʼ֪ͨ');
@define('INSTALL_SUBSCRIBE', 'ʹ߶?');
@define('INSTALL_SUBSCRIBE_DESC', 'ʹյʼ֪ͨ, лظʱǻյ֪ͨ');
@define('INSTALL_BLOGNAME', 'վ');
@define('INSTALL_BLOGNAME_DESC', 'վ');
@define('INSTALL_BLOGDESC', 'վ');
@define('INSTALL_BLOGDESC_DESC', '־');
@define('INSTALL_LANG', '');
@define('INSTALL_LANG_DESC', 'վʹõ');

/* Appearance and options */
@define('INSTALL_CAT_DISPLAY', '⼰ѡ趨');
@define('INSTALL_CAT_DISPLAY_DESC', '趨ϵͳ趨');
@define('INSTALL_WYSIWYG', 'ʹ WYSIWYG ༭');
@define('INSTALL_WYSIWYG_DESC', 'Ҫʹ WYSIWYG ༭( IE5+ ʹ, ĳЩֿʹ Mozilla 1.3+)');
@define('INSTALL_XHTML11', 'ǿƷ XHTML 1.1 Ҫ');
@define('INSTALL_XHTML11_DESC', 'ϵͳǿƷ XHTML 1.1 Ҫ (Ծɵ)');
@define('INSTALL_POPUP', 'ʹõ');
@define('INSTALL_POPUP_DESC', 'Ҫڻظõȵطʹõ');
@define('INSTALL_EMBED', 'ʹǶ?');
@define('INSTALL_EMBED_DESC', 'Ҫ Serendipity Ƕķʽŵҳ, ѡ  καȻֻʾվݡ  indexFile 趨ܡѯ README ļ!');
@define('INSTALL_TOP_AS_LINKS', 'ӷʽʾ ҪԴ/ҪԴ');
@define('INSTALL_TOP_AS_LINKS_DESC', '"": ԴԴʾ google Ĺ档 "": ԴԴʾ. "Ԥ": ȫ趨 ()');
@define('INSTALL_BLOCKREF', '赲Դ');
@define('INSTALL_BLOCKREF_DESC', 'վԴʾ?  \';\' ֿվ, עַʽ赲ģ');
@define('INSTALL_REWRITE', 'URL Rewriting');
@define('INSTALL_REWRITE_DESC', 'ѡ URL Rewriting ʽ rewrite ԱȽķʽʾ URL, Ավȷ¼£֧ mod_rewrite  "AllowOverride All" Ĺܡ[Ԥ趨ϵͳԶ]');

/* Imageconversion Settings */
@define('INSTALL_CAT_IMAGECONV', 'ͼƬת趨');
@define('INSTALL_CAT_IMAGECONV_DESC', '趨ͼƬתķʽ');
@define('INSTALL_IMAGEMAGICK', 'ʹ Imagemagick');
@define('INSTALL_IMAGEMAGICK_DESC', 'װ image magick, ҪıͼƬС?');
@define('INSTALL_IMAGEMAGICKPATH', 'תʽ·');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'image magick תʽȫ·');
@define('INSTALL_THUMBSUFFIX', 'ͼַ');
@define('INSTALL_THUMBSUFFIX_DESC', 'ͼĸʽ: original.[ַ].ext');
@define('INSTALL_THUMBWIDTH', 'ͼС');
@define('INSTALL_THUMBWIDTH_DESC', 'Զͼ');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', '趨');
@define('USERCONF_CAT_PERSONAL_DESC', 'ıĸ');
@define('USERCONF_USERNAME', 'ʺ');
@define('USERCONF_USERNAME_DESC', 'ϵͳ');
@define('USERCONF_PASSWORD', '');
@define('USERCONF_PASSWORD_DESC', 'ϵͳ');
@define('USERCONF_EMAIL', 'ĵʼ');
@define('USERCONF_EMAIL_DESC', 'ʹõĵʼ');
@define('USERCONF_SENDCOMMENTS', 'ͻظ֪ͨ');
@define('USERCONF_SENDCOMMENTS_DESC', '»ظʱʹ֪ͨ');
@define('USERCONF_SENDTRACKBACKS', '֪ͨ?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'ʱʹ֪ͨ');
@define('USERCONF_ALLOWPUBLISH', 'Ȩ: ɷ');
@define('USERCONF_ALLOWPUBLISH_DESC', 'λ߷');
@define('SUCCESS', '');
@define('POWERED_BY_SHOW_TEXT', 'ʾ "Serendipity"');
@define('POWERED_BY_SHOW_TEXT_DESC', 'ʾ "Serendipity Weblog"');
@define('POWERED_BY_SHOW_IMAGE', ' logo ʾ "Serendipity"');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'ʾ Serendipity  logo');
@define('PLUGIN_ITEM_DISPLAY', 'Ŀʾַ');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'ֻڸʾ');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'ֻڿʾ');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'Զʾ');

@define('COMMENTS_WILL_BE_MODERATED', 'ĻظҪԱ');
@define('YOU_HAVE_THESE_OPTIONS', 'ѡ:');
@define('THIS_COMMENT_NEEDS_REVIEW', ': ظ˲Żʾ');
@define('DELETE_COMMENT', 'ɾظ');
@define('APPROVE_COMMENT', '˻ظ');
@define('REQUIRES_REVIEW', 'Ҫ');
@define('COMMENT_APPROVED', 'ظ #%s Ѿͨ');
@define('COMMENT_DELETED', 'ظ #%s Ѿɹɾ');
@define('COMMENTS_MODERATE', 'ظҪԱ');
@define('THIS_TRACKBACK_NEEDS_REVIEW', ': ҪԱ˲Żʾ');
@define('DELETE_TRACKBACK', 'ɾ');
@define('APPROVE_TRACKBACK', '');
@define('TRACKBACK_APPROVED', ' #%s Ѿͨ');
@define('TRACKBACK_DELETED', ' #%s Ѿɹɾ');
@define('VIEW', '');
@define('COMMENT_ALREADY_APPROVED', 'ظ #%s Ѿͨ');
@define('COMMENT_EDITED', 'ѱ༭');
@define('HIDE', '');
@define('VIEW_EXTENDED_ENTRY', 'Ķ "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'Ӳ. µ URI. Դ URI  ping õ. Ҫ, ϵҼȻѡ "" (IE)  "ӵַ" (Mozilla).');
@define('PLUGIN_SUPERUSER_HTTPS', ' https ');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'ʹ https ַ֧');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'ⲿʾ');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"": ⲿ (ҪԴ, ҪԴ, ظ) ʾ google  (ʹ) "": ӽԳӵķʽʾ ڲҸǴ趨');
@define('PAGE_BROWSE_COMMENTS', 'ҳ %s  %s, ܹ %s ظ');
@define('FILTERS', '');
@define('FIND_ENTRIES', '');
@define('FIND_COMMENTS', 'ظ');
@define('FIND_MEDIA', 'ý');
@define('FILTER_DIRECTORY', 'Ŀ¼');
@define('SORT_BY', '');
@define('TRACKBACK_COULD_NOT_CONNECT', 'ûͳ: ޷· %s ӵ %d');
@define('MEDIA', 'ý');
@define('MEDIA_LIBRARY', 'ýͼ');
@define('ADD_MEDIA', 'ý');
@define('ENTER_MEDIA_URL', 'ļַ:');
@define('ENTER_MEDIA_UPLOAD', 'ѡҪϴļ:');
@define('SAVE_FILE_AS', 'ļ:');
@define('STORE_IN_DIRECTORY', '浽Ŀ¼: ');
@define('ADD_MEDIA_BLAHBLAH', '<b>ļýĿ¼:</b><p>ϴýļ, ϵͳѰҡûҪͼƬ, Ե <a href="http://images.google.com" target="_blank">googleͼƬ</a>.<p><b>ѡʽ:</b><br>');
@define('MEDIA_RENAME', 'ļ');
@define('IMAGE_RESIZE', 'ͼƬߴ');
@define('MEDIA_DELETE', 'ɾļ');
@define('FILES_PER_PAGE', 'ÿҳʾļ');
@define('CLICK_FILE_TO_INSERT', 'ѡҪļ:');
@define('SELECT_FILE', 'ѡҪļ');
@define('MEDIA_FULLSIZE', 'ߴ');
@define('CALENDAR_BOW_DESC', 'һڵĵһ[Ԥһ]');
@define('SUPERUSER', 'ϵͳ');
@define('ALLOWS_YOU_BLAHBLAH', 'ڲṩӵ־');
@define('CALENDAR', 'վ');
@define('SUPERUSER_OPEN_ADMIN', 'ҳ');
@define('SUPERUSER_OPEN_LOGIN', 'ҳ');
@define('INVERT_SELECTIONS', 'ѡ');
@define('COMMENTS_DELETE_CONFIRM', 'ȷҪɾѡĻظ');
@define('COMMENT_DELETE_CONFIRM', 'ȷҪɾظ #%d,  %s');
@define('DELETE_SELECTED_COMMENTS', 'ɾѡĻظ');
@define('VIEW_COMMENT', 'ظ');
@define('VIEW_ENTRY', '');
@define('DELETE_FILE_FAIL' , '޷ɾļ <b>%s</b>');
@define('DELETE_THUMBNAIL', 'ɾͼƬͼ <b>%s</b>');
@define('DELETE_FILE', 'ɾļ <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', '㽫ɾļ <b>%s</b><br />ʹļ, ǸӻͼƬЧ<br />ȷҪ<br /><br />');
@define('TRACKBACK_SENDING', 'õ URI %s...');
@define('TRACKBACK_SENT', '');
@define('TRACKBACK_FAILED', 'ô: %s');
@define('TRACKBACK_NOT_FOUND', 'Ҳõĵַ');
@define('TRACKBACK_URI_MISMATCH', 'ԶѰøĿ겻ͬ.');
@define('TRACKBACK_CHECKING', 'Ѱ <u>%s</u> ...');
@define('TRACKBACK_NO_DATA', 'Ŀûκ');
@define('TRACKBACK_SIZE', 'Ŀַ %s bytes ļС.');
@define('COMMENTS_VIEWMODE_THREADED', '߳');
@define('COMMENTS_VIEWMODE_LINEAR', 'ֱ߳');
@define('DISPLAY_COMMENTS_AS', 'ظʾʽ');
@define('COMMENTS_FILTER_SHOW', 'ʾ');
@define('COMMENTS_FILTER_ALL', 'ȫ');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'ʾ˻ظ');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'ʾȴ');
@define('RSS_IMPORT_BODYONLY', 'ַŵ, 𿪹µ');
@define('SYNDICATION_PLUGIN_FULLFEED', ' RSS feed ʾȫ');
@define('WEEK', '');
@define('WEEKS', '');
@define('MONTHS', '');
@define('DAYS', '');
@define('ARCHIVE_FREQUENCY', 'ļƵ');
@define('ARCHIVE_FREQUENCY_DESC', 'ļʹõĿ嵥');
@define('ARCHIVE_COUNT', 'ļĿ');
@define('ARCHIVE_COUNT_DESC', 'ʾ, , ');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'ǰװõ');
@define('SIDEBAR_PLUGIN', '');
@define('EVENT_PLUGIN', '¼');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'ﰲװ %s');
@define('VERSION', '汾');
@define('INSTALL', 'װ');
@define('ALREADY_INSTALLED', 'Ѿװ');
@define('SELECT_A_PLUGIN_TO_ADD', 'ѡҪװ');
@define('RSS_IMPORT_CATEGORY', 'ͬ');

@define('INSTALL_OFFSET', 'ʱ'); // Translate
@define('STICKY_POSTINGS', 'ö'); // Translate
@define('INSTALL_FETCHLIMIT', 'ҳʾ'); // Translate
@define('INSTALL_FETCHLIMIT_DESC', 'ҳʾµ'); // Translate
@define('IMPORT_ENTRIES', ''); // Translate
@define('EXPORT_ENTRIES', ''); // Translate
@define('IMPORT_WELCOME', 'ӭʹSerendipityת'); // Translate
@define('IMPORT_WHAT_CAN', 'Ե'); // Translate
@define('IMPORT_SELECT', 'ѡҪĳ'); // Translate
@define('IMPORT_PLEASE_ENTER', ''); // Translate
@define('IMPORT_NOW', 'ʼ'); // Translate
@define('IMPORT_STARTING', 'ڵ...'); // Translate
@define('IMPORT_FAILED', 'ʧ'); // Translate
@define('IMPORT_DONE', 'ɹ'); // Translate
@define('IMPORT_WEBLOG_APP', ''); // Translate
@define('EXPORT_FEED', ' RSS feed'); // Translate
@define('STATUS', '״̬'); // Translate
@define('IMPORT_GENERIC_RSS', 'һ RSS '); // Translate
@define('ACTIVATE_AUTODISCOVERY', 'õ'); // Translate
@define('WELCOME_TO_ADMIN', 'ӭ½Serendipityܲϵͳ');
@define('PLEASE_ENTER_CREDENTIALS', 'ȷĵ½ʺ'); // Translate
@define('ADMIN_FOOTER_POWERED_BY', 'Powered by Serendipity %s and PHP %s'); // Translate
@define('INSTALL_USEGZIP', 'ʹ gzip ѹҳ'); // Translate
@define('INSTALL_USEGZIP_DESC', 'Ϊҳеø, ϵͳѹʾ, ÿʹõ֧ѹҳĻʹá'); // Translate
@define('INSTALL_SHOWFUTURE', 'ʾδ'); // Translate
@define('INSTALL_SHOWFUTURE_DESC', ', ϵͳʾδ£Ԥ趨δأȻ󵽷Զʾ'); // Translate
@define('INSTALL_DBPERSISTENT', 'ʹó'); // Translate
@define('INSTALL_DBPERSISTENT_DESC', 'ݿʹó,  <a href="http://php.net/manual/features.persistent-connections.php" target="_blank"></a>ͨʹá'); // Translate
@define('NO_IMAGES_FOUND', 'Ҳļ'); // Translate
@define('PERSONAL_SETTINGS', ''); // Translate
@define('REFERER', 'Դ'); // Translate
@define('NOT_FOUND', 'Ҳ'); // Translate
@define('NOT_WRITABLE', 'ɶд'); // Translate
@define('WRITABLE', 'ɶд'); // Translate
@define('PROBLEM_DIAGNOSTIC', 'Ϊ,˲ܰװ'); // Translate
@define('SELECT_INSTALLATION_TYPE', 'ѡװ'); // Translate
@define('WELCOME_TO_INSTALLATION', 'ӭʹ Serendipity İ'); // Translate
@define('FIRST_WE_TAKE_A_LOOK', 'ϵͳԱⰲװ'); // Translate
@define('ERRORS_ARE_DISPLAYED_IN', 'ʾ %s,  %s  %s'); // Translate
@define('RED', ''); // Translate
@define('YELLOW', ''); // Translate
@define('GREEN', ''); // Translate
@define('PRE_INSTALLATION_REPORT', 'Serendipity Blog v%s װǰ'); // Translate
@define('RECOMMENDED', ''); // Translate
@define('ACTUAL', 'ʵ'); // Translate
@define('PHPINI_CONFIGURATION', 'php.ini '); // Translate
@define('PHP_INSTALLATION', 'PHP װ'); // Translate
@define('THEY_DO', 'ͨ'); // Translate
@define('THEY_DONT', 'they don\'t'); // Translate
@define('SIMPLE_INSTALLATION', 'ٰװ'); // Translate
@define('EXPERT_INSTALLATION', '߼װ'); // Translate
@define('COMPLETE_INSTALLATION', 'װ'); // Translate
@define('WONT_INSTALL_DB_AGAIN', 'ظװݿ'); // Translate
@define('CHECK_DATABASE_EXISTS', 'Ƿ'); // Translate
@define('CREATING_PRIMARY_AUTHOR', '趨Ա \'%s\''); // Translate
@define('SETTING_DEFAULT_TEMPLATE', '趨'); // Translate
@define('INSTALLING_DEFAULT_PLUGINS', 'װԤ趨'); // Translate
@define('SERENDIPITY_INSTALLED', 'Serendipityİ氲װ'); // Translate
@define('VISIT_BLOG_HERE', 'ʼĲ'); // Translate
@define('THANK_YOU_FOR_CHOOSING', 'ǳлѡ Serendipityİ'); // Translate
@define('ERROR_DETECTED_IN_INSTALL', 'װʱ'); // Translate
@define('OPERATING_SYSTEM', 'ϵͳ'); // Translate
@define('WEBSERVER_SAPI', ' SAPI'); // Translate
@define('TEMPLATE_SET', '\'%s\' ѱ趨Ϊ'); // Translate
@define('SEARCH_ERROR', 'ִܳ󣬱Ա:ݿûȷindex keys,ʹMYSQLʺűִ <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> ȨޣݿʾĴ: <pre>%s</pre>'); // Translate
@define('EDIT_THIS_CAT', '༭ "%s"'); // Translate
@define('CATEGORY_REMAINING', 'ɾȻת'); // Translate
@define('CATEGORY_INDEX', 'ǿתƵķ'); // Translate
@define('NO_CATEGORIES', 'ûз'); // Translate
@define('RESET_DATE', ''); // Translate
@define('RESET_DATE_DESC', ''); // Translate
@define('PROBLEM_PERMISSIONS_HOWTO', 'Ȩ޿ʹ shell ִ: `<em>%s</em>` ȻִҪĵļ, ʹ FTP '); // Translate
@define('WARNING_TEMPLATE_DEPRECATED', ':  ĿǰʹõǾɷģ뾡'); // Translate
@define('ENTRY_PUBLISHED_FUTURE', 'ƪδ'); // Translate
@define('ENTRIES_BY', ' %s'); // Translate
@define('PREVIOUS', 'һҳ'); // Translate
@define('NEXT', 'һҳ'); 
@define('APPROVE', ''); 

@define('DO_MARKUP_DESCRIPTION', 'Զʽ (,  *, /, _, ...)رܽᱣκڳֵ HTML ﷨');
@define('CATEGORY_ALREADY_EXIST', ' "%s" Ѿ');
@define('IMPORT_NOTES', 'ע:');
@define('ERROR_FILE_FORBIDDEN', '㲻ϴļ');
@define('ADMIN', 'Ҫ趨');
@define('ADMIN_FRONTPAGE', 'ҳ');
@define('QUOTE', '');
@define('IFRAME_SAVE', 'ڱ£úִ XML-RPC callsԺ..');
@define('IFRAME_SAVE_DRAFT', '²ݸѱ');
@define('IFRAME_PREVIEW', 'ڽԤ...');
@define('IFRAME_WARNING', '֧ iframes.  serendipity_config.inc.php ļȻ趨 $serendipity[\'use_iframe\'] Ϊ FALSE');
@define('NONE', 'None');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', '½ʹԤ趨');
@define('UPGRADE', '');
@define('UPGRADE_TO_VERSION', '°汾 %s');
@define('DELETE_DIRECTORY', 'ɾĿ¼');
@define('DELETE_DIRECTORY_DESC', 'ɾĿ¼ڵýļעļҲڡ');
@define('FORCE_DELETE', 'ɾĿ¼ڵļ޷ʶļ');
@define('CREATE_DIRECTORY', 'Ŀ¼');
@define('CREATE_NEW_DIRECTORY', 'Ŀ¼');
@define('CREATE_DIRECTORY_DESC', 'ԽµĿ¼ýļĿ¼ƺѡǷŵĿ¼ڡ');
@define('BASE_DIRECTORY', 'Ŀ¼');
@define('USERLEVEL_EDITOR_DESC', 'һ');
@define('USERLEVEL_CHIEF_DESC', '');
@define('USERLEVEL_ADMIN_DESC', 'Ա');
@define('USERCONF_USERLEVEL', 'Ȩ');
@define('USERCONF_USERLEVEL_DESC', 'ѡ趨־ڵȨ');
@define('USER_SELF_INFO', 'û %s (%s)');
@define('ADMIN_ENTRIES', '¹');// Ą̊́˵¹
@define('RECHECK_INSTALLATION', '¼鰲װ');
@define('IMAGICK_EXEC_ERROR', '޷ִ: "%s", : %s, ϵ: %d');
@define('INSTALL_OFFSET_DESC', 'Сʱ㣬ʱ (Ŀǰ: %clock%) ʱ');
@define('UNMET_REQUIREMENTS', 'δﵽ: %s');
@define('CHARSET', '');
@define('AUTOLANG', 'ʹ趨ı');
@define('AUTOLANG_DESC', 'ܽʹ趨ı');
@define('INSTALL_AUTODETECT_URL', 'Զ HTTP-Host');
@define('INSTALL_AUTODETECT_URL_DESC', '趨Ϊ "true"HTTP Host ĵַ趨ͬܿʹö־ʹ־ӡ');
@define('CONVERT_HTMLENTITIES', 'Զı HTML ıǩ');
@define('EMPTY_SETTING', 'ûṩ "%s" ȷ');
@define('USERCONF_REALNAME', 'ȫ');
@define('USERCONF_REALNAME_DESC', 'ȫʾȫ');
@define('HOTLINK_DONE', 'ļⲿ<br />');
@define('ENTER_MEDIA_URL_METHOD', 'ȡ÷:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'ע:ѡⲿӣȵõԴվⲿվͼƬҪͼƬڡ');
@define('MEDIA_HOTLINKED', 'ⲿͼƬ');
@define('FETCH_METHOD_IMAGE', 'ͼƬ');
@define('FETCH_METHOD_HOTLINK', 'ⲿӵ');
@define('DELETE_HOTLINK_FILE', 'ɾⲿӵļ <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'ʾʼ');
@define('IMAGE_MORE_INPUT', 'ͼƬ');
@define('BACKEND_TITLE', 'ҳĶϢ');
@define('BACKEND_TITLE_FOR_NUGGET', '趨һЩԶ֣ HTML Nugget һʾҳ档ж HTML Nuggetsֱͬҡ');
@define('CATEGORIES_ALLOW_SELECT', 'ÿʾ');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'ѡ sidebar Ա߻ֹѡ˵ԱԹѡҪʾ');
@define('PAGE_BROWSE_PLUGINS', 'ҳ %s  %s, ܹ %s ҡ');
@define('INSTALL_CAT_PERMALINKS', '̬');
@define('INSTALL_CAT_PERMALINKS_DESC', 'øֲַͬʽ徲̬ӡԤʽʹ %id% ֵݿѰҵַĿꡣ');
@define('INSTALL_PERMALINK', 'µľ̬');
@define('INSTALL_PERMALINK_DESC', '趨Իλµӡ²%id%, %title%, %day%, %month%, %year% ַ');
@define('INSTALL_PERMALINK_AUTHOR', 'ߵľ̬');
@define('INSTALL_PERMALINK_AUTHOR_DESC', '趨Իλµӡ²%id%, %realname%, %username%, %email% ַ');
@define('INSTALL_PERMALINK_CATEGORY', 'ľ̬');
@define('INSTALL_PERMALINK_CATEGORY_DESC', '趨Իλµӡ²%id%, %name%, %description% ַ');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'RSS-Feed ľ̬');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', '趨Իλ RSS-Feed µӡ²%id%, %name%, %description% ַ');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'ļ·');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'ļ·');
@define('INSTALL_PERMALINK_CATEGORIESPATH', '·');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Ļظ·');
@define('INSTALL_PERMALINK_DELETEPATH', 'ɾظ·');
@define('INSTALL_PERMALINK_APPROVEPATH', '׼ظ·');
@define('INSTALL_PERMALINK_FEEDSPATH', 'RSS Feeds ·');
@define('INSTALL_PERMALINK_PLUGINPATH', '·');
@define('INSTALL_PERMALINK_ADMINPATH', '·');
@define('INSTALL_PERMALINK_SEARCHPATH', '·');
@define('INSTALL_CAL', '');
@define('INSTALL_CAL_DESC', 'ѡҪ');
@define('REPLY', 'ظ');
@define('USERCONF_GROUPS', 'ԱȺ');
@define('USERCONF_GROUPS_DESC', '˻ԱȺԱԱԼȺ顣');
@define('MANAGE_GROUPS', 'Ⱥ');
@define('DELETED_GROUP', 'Ⱥ #%d %s ɾ');
@define('CREATED_GROUP', 'Ⱥ %s ');
@define('MODIFIED_GROUP', 'Ⱥ %s 趨ѱı');
@define('GROUP', 'Ⱥ');
@define('CREATE_NEW_GROUP', 'Ⱥ');
@define('DELETE_GROUP', 'ȷҪɾȺ #%d %s ');
@define('USERLEVEL_OBSOLETE', 'ע: ԱȨ޵ֻΪֻظļݺȨϵͳʹµĻԱȨޡ');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'Ҫµ ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurner ͼƬ');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'λ feedburner.com ͼƬʾ (հʾ)磺fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurner ');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'ʾͼƬԵı ()');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner ͼƬ');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'ͼƬʱʾ ()');
@define('SEARCH_TOO_SHORT', 'Ѱֱ3ֽڡʹ * 棬ѰֽС 3 ֽڡ磺s9y*');
@define('INSTALL_DBPORT', 'ݿӶ');
@define('INSTALL_DBPORT_DESC', 'ݿʹõӶ');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'ǰˣⲿ');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'ǰˣ');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'ǰˣ');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'ǰˣ');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'ǰˣ');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'ˣ༭');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'ˣԱ');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'ˣMeta ');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'ˣ');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'ˣ');
@define('PLUGIN_GROUP_IMAGES', 'ͼƬ');
@define('PLUGIN_GROUP_ANTISPAM', 'ֹ');
@define('PLUGIN_GROUP_MARKUP', '');
@define('PLUGIN_GROUP_STATISTICS', 'ͳ');
@define('PERMISSION_PERSONALCONFIGURATION', 'ȡ˽趨');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'ıԱȨ');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', ' "ֹ"');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'µȨ');
@define('PERMISSION_SITECONFIGURATION', 'ȡϵͳ趨');
@define('PERMISSION_BLOGCONFIGURATION', 'ȡ־趨');
@define('PERMISSION_ADMINENTRIES', '');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'Ա');
@define('PERMISSION_ADMINIMPORT', '');
@define('PERMISSION_ADMINCATEGORIES', '');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'Ա');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'ɾ');
@define('PERMISSION_ADMINUSERS', 'Ա');
@define('PERMISSION_ADMINUSERSDELETE', 'ɾԱ');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'Ȩ');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'ͬȺĻԱ');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'admin: maintainOthers');
@define('PERMISSION_ADMINUSERSCREATENEW', 'Ա');
@define('PERMISSION_ADMINUSERSGROUPS', 'Ⱥ');
@define('PERMISSION_ADMINPLUGINS', '');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'Ա');
@define('PERMISSION_ADMINIMAGES', 'ýļ');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'ýĿ¼');
@define('PERMISSION_ADMINIMAGESADD', 'ýļ');
@define('PERMISSION_ADMINIMAGESDELETE', 'ɾýļ');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'Աýļ');
@define('PERMISSION_ADMINIMAGESVIEW', 'ýļ');
@define('PERMISSION_ADMINIMAGESSYNC', 'ͬͼ');
@define('PERMISSION_ADMINCOMMENTS', 'ظ');
@define('PERMISSION_ADMINTEMPLATES', '');
@define('INSTALL_BLOG_EMAIL', 'վĵʼ');
@define('INSTALL_BLOG_EMAIL_DESC', '趨ĵʼκ־ڼĳʼʾʼַǵʼڣܾܶղʼ');
@define('CATEGORIES_PARENT_BASE', 'ֻʾ...');
@define('CATEGORIES_PARENT_BASE_DESC', 'ѡһֻʾ');
@define('CATEGORIES_HIDE_PARALLEL', 'زṹ');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'λṹȿ趨ͨڶ־ҡ');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'Աýļ');
@define('CHARSET_NATIVE', 'Ԥ');
@define('INSTALL_CHARSET', 'ѡ');
@define('INSTALL_CHARSET_DESC', 'ת UTF-8 Ԥ (ISO, GB2312, ...)Щ԰ֻ UTF-8 룬ԻԤвκθı䡣°װ־ʹ UTF-8 롣ǵòҪı趨Ѿ¡ http://www.s9y.org/index.php?node=46');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'External Events');
@define('CALENDAR_EXTEVENT_DESC', 'ҿɫʾ¼ûʹЩң鲻Ҫʹá');
@define('XMLRPC_NO_LONGER_BUNDLED', 'XML-RPC API ܲ s9y İװΪ©ͲʹõĹϵԱ밲װ XML-RPC ʹ XML-RPC APIе URL ˸ı䣬װҺʹá');
@define('PERM_READ', 'ȡȨ');
@define('PERM_WRITE', 'дȨ');

@define('PERM_DENIED', 'Ȩ޾ܾ');
@define('INSTALL_ACL', 'ȡȨ޵');
@define('INSTALL_ACL_DESC', 'ȺȨ趨õĻԱرգĶȡȨ޲ᱻʹãǻӿ־ٶȡ㲻ҪʹߵĶȡȨޣ㽫趨رա');
@define('PLUGIN_API_VALIDATE_ERROR', 'õ趨 "%s" ﷨Ҫ "%s" ͡');
@define('USERCONF_CHECK_PASSWORD', '');
@define('USERCONF_CHECK_PASSWORD_DESC', 'Ҫ룬뽫뵽');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'ṩ˴ľԲܸ롣趨δ档');
@define('ERROR_XSRF', '˴ HTTP-Referrer ַΪ browser/proxy Ĵ趨 Cross Site Request Forgery (XSRF) ĹϵĲ޷ɡ');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', '㶨 URL ӻ URL Աȡ RSS-feeds Ϊ׼Щ %id%, %realname%, %username%, %email% ַ');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Permalink RSS-Feed ߵ URL');
@define('INSTALL_PERMALINK_AUTHORSPATH', '·');
@define('AUTHORS', '');
@define('AUTHORS_ALLOW_SELECT', 'ÿʾλ?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'ѡÿͿԹѡҪȡߵ¡');
@define('AUTHOR_PLUGIN_DESC', 'ʾб');
@define('CATEGORY_PLUGIN_TEMPLATE', ' Smarty-Templates');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'ѡһ Smarty-Templating ĹбҲ "plugin_categories.tpl" ģļıۡѡҳʾٶȣ㲻κθı䣬ùرѡ');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'ʾÿ');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'ʾߵ');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', '趨ߵ»ʾԡ');
@define('CUSTOM_ADMIN_INTERFACE', 'ԶĹ');

@define('COMMENT_NOT_ADDED', 'ĻظܼΪƪ²ظ˴Ϣͨ'); 
@define('INSTALL_TRACKREF', '¼Դ');
@define('INSTALL_TRACKREF_DESC', '¼ԴʾǸվ¡Թرյ̫档');
@define('CATEGORIES_HIDE_PARENT', 'ѡ');
@define('CATEGORIES_HIDE_PARENT_DESC', 'ʾбԤǻʾơܣƽʾ');
@define('WARNING_NO_GROUPS_SELECTED', '棺ûѡԱȺ顣ὫǳȺĹԱȺ鲻ᱻı䡣');
@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'RSS Feed ҳʾ');
@define('INSTAL_DB_UTF8', 'ݿת');
@define('INSTAL_DB_UTF8_DESC', 'ʹ MySQL  "SET NAMES" ѯ趨롣³Խ趨򿪻رա');
@define('ONTHEFLYSYNCH', 'ýͬ');
@define('ONTHEFLYSYNCH_DESC', 'Serendipity BlogȽݿýĿ¼ļȻͬ');
@define('USERCONF_CHECK_USERNAME_ERROR', 'ʺŲܿհ');
@define('FURTHER_LINKS', '');
@define('FURTHER_LINKS_S9Y', 'ٷҳ');
@define('FURTHER_LINKS_S9Y_DOCS', '֧');
@define('FURTHER_LINKS_S9Y_BLOG', 'վ־');
@define('FURTHER_LINKS_S9Y_FORUMS', '̳');
@define('FURTHER_LINKS_S9Y_SPARTACUS', '');
@define('COMMENT_IS_DELETED', '(ظɾ)');

@define('CURRENT_AUTHOR', 'Ŀǰ');

@define('WORD_NEW', '');
@define('SHOW_MEDIA_TOOLBAR', 'ѡýӴʾ');
@define('MEDIA_KEYWORDS', 'ýĹؼ');
@define('MEDIA_KEYWORDS_DESC', 'Ԥýؼ֣ ";" ֿÿؼ֡');
@define('MEDIA_EXIF', ' EXIF/JPEG ͼƬ');
@define('MEDIA_EXIF_DESC', 'EXIF/JPEG ͼ metadata Զ浽ݿ⡣');
@define('MEDIA_PROP', 'ý');


@define('GO_ADD_PROPERTIES', '');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Ȩ');
@define('MEDIA_PROPERTY_COMMENT1', '̽');
@define('MEDIA_PROPERTY_COMMENT2', '');
@define('MEDIA_PROPERTY_TITLE', '');
@define('MEDIA_PROP_DESC', 'ýʹõݲ˵ ";" ֿÿ˵');
@define('MEDIA_PROP_MULTIDESC', '(ƺ ":MULTI" 趨Ӵ)');

@define('STYLE_OPTIONS_NONE', 'ûرѡҪѡ www.s9y.org ڵ Technical DocumentationȻ "Configuration of Theme options"');
@define('STYLE_OPTIONS', 'ѡ');

@define('PLUGIN_AVAILABLE_COUNT', 'ܹ %d ');

@define('SYNDICATION_RFC2616', 'ϸ RFC2616 RSS-Feed');
@define('SYNDICATION_RFC2616_DESC', 'ǿ RFC2616 ʾȫ GETs  Serendipity Blog ֻᴫ޸ĵ¡趨Ϊ "false" ʾÿͽȫ¡һЩ־ĳ Planet ʾΥ RFC2616 ı׼趨Ϊ "TRUE" ʾ RFC ı׼ÿͿܶȡȫ¡˵޷չ˵ģ<a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', '');
@define('MEDIA_PROPERTY_RUN_LENGTH', '');
@define('FILENAME_REASSIGNED', 'Զָļƣ %s');
@define('MEDIA_UPLOAD_SIZE', 'ļС');
@define('MEDIA_UPLOAD_SIZE_DESC', 'ļֵ趨ҲԴڵ PHP.ini ļı䣺 upload_max_filesize, post_max_size, max_input_time ȫ趨Чʾơ');
@define('MEDIA_UPLOAD_SIZEERROR', '㲻ϴ %s ֽڵļ');
@define('MEDIA_UPLOAD_MAXWIDTH', 'ͼƬ');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'ϴͼƬȡ');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'ͼƬ󳤶');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'ϴͼƬ󳤶ȡ');
@define('MEDIA_UPLOAD_DIMERROR', '㲻ϴ %s x %s ͼƬ');

@define('MEDIA_TARGET', 'ӵĿ');
@define('MEDIA_TARGET_JS', ' (ʹ JavaScript)');
@define('MEDIA_ENTRY', '');
@define('MEDIA_TARGET_BLANK', ' (ʹ target=_blank)');

@define('MEDIA_DYN_RESIZE', 'ıͼƬС');
@define('MEDIA_DYN_RESIZE_DESC', 'ýѡӴʾ GET 趨ͼƬСͼƬᱣڻڣԳʹûռĿռ䡣');

@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
@define('PLUGIN_ACTIVE', 'Active');
@define('PLUGIN_INACTIVE', 'Inactive');
@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');
@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');
@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
@define('SET_TO_MODERATED', 'Moderate');
@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
@define('CENTER', 'center');
